MIN_ROW = 0
MAX_ROW = 9
MIN_COL = 0
MAX_COL = 8
NUM_ROWS = MAX_ROW - MIN_ROW + 1
NUM_COLS = MAX_COL - MIN_COL + 1

CASTLE_MIN_COL = 3
CASTLE_MAX_COL = 5
CASTLE_TOP_MIN_ROW = 0
CASTLE_TOP_MAX_ROW = 2
CASTLE_BOT_MIN_ROW = 7
CASTLE_BOT_MAX_ROW = 9

HAN_ADVANTAGE = 1.5